aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/com/jogamp/opengl/util/glsl/fixedfunc
diff options
context:
space:
mode:
Diffstat (limited to 'src/jogl/classes/com/jogamp/opengl/util/glsl/fixedfunc')
-rw-r--r--src/jogl/classes/com/jogamp/opengl/util/glsl/fixedfunc/FixedFuncUtil.java38
1 files changed, 19 insertions, 19 deletions
diff --git a/src/jogl/classes/com/jogamp/opengl/util/glsl/fixedfunc/FixedFuncUtil.java b/src/jogl/classes/com/jogamp/opengl/util/glsl/fixedfunc/FixedFuncUtil.java
index 1ed875f27..37bca895a 100644
--- a/src/jogl/classes/com/jogamp/opengl/util/glsl/fixedfunc/FixedFuncUtil.java
+++ b/src/jogl/classes/com/jogamp/opengl/util/glsl/fixedfunc/FixedFuncUtil.java
@@ -4,12 +4,12 @@
package com.jogamp.opengl.util.glsl.fixedfunc;
-import javax.media.opengl.GL;
-import javax.media.opengl.GL2ES1;
-import javax.media.opengl.GL2ES2;
-import javax.media.opengl.GLContext;
-import javax.media.opengl.GLException;
-import javax.media.opengl.fixedfunc.GLPointerFuncUtil;
+import com.jogamp.opengl.GL;
+import com.jogamp.opengl.GL2ES1;
+import com.jogamp.opengl.GL2ES2;
+import com.jogamp.opengl.GLContext;
+import com.jogamp.opengl.GLException;
+import com.jogamp.opengl.fixedfunc.GLPointerFuncUtil;
import jogamp.opengl.util.glsl.fixedfunc.FixedFuncHook;
import jogamp.opengl.util.glsl.fixedfunc.FixedFuncImpl;
@@ -77,18 +77,18 @@ public class FixedFuncUtil {
* Useful for uniq mapping of canonical array index names as listed.
*
* @see #mgl_Vertex
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#GL_VERTEX_ARRAY
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#GL_VERTEX_ARRAY
* @see #mgl_Normal
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#GL_NORMAL_ARRAY
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#GL_NORMAL_ARRAY
* @see #mgl_Color
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#GL_COLOR_ARRAY
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#GL_COLOR_ARRAY
* @see #mgl_MultiTexCoord
* @see javax.media.opengl.fixedfunc.GLPointerFunc#GL_TEXTURE_COORD_ARRAY
* @see javax.media.opengl.fixedfunc.GLPointerFunc#glEnableClientState
* @see javax.media.opengl.fixedfunc.GLPointerFunc#glVertexPointer
* @see javax.media.opengl.fixedfunc.GLPointerFunc#glColorPointer
* @see javax.media.opengl.fixedfunc.GLPointerFunc#glNormalPointer
* @see javax.media.opengl.fixedfunc.GLPointerFunc#glTexCoordPointer
*/
public static String getPredefinedArrayIndexName(final int glArrayIndex) {
return GLPointerFuncUtil.getPredefinedArrayIndexName(glArrayIndex);
@@ -96,25 +96,25 @@ public class FixedFuncUtil {
/**
* String name for
- * @see javax.media.opengl.GL2#GL_VERTEX_ARRAY
+ * @see com.jogamp.opengl.GL2#GL_VERTEX_ARRAY
*/
public static final String mgl_Vertex = GLPointerFuncUtil.mgl_Vertex;
/**
* String name for
- * @see javax.media.opengl.GL2#GL_NORMAL_ARRAY
+ * @see com.jogamp.opengl.GL2#GL_NORMAL_ARRAY
*/
public static final String mgl_Normal = GLPointerFuncUtil.mgl_Normal;
/**
* String name for
- * @see javax.media.opengl.GL2#GL_COLOR_ARRAY
+ * @see com.jogamp.opengl.GL2#GL_COLOR_ARRAY
*/
public static final String mgl_Color = GLPointerFuncUtil.mgl_Color;
/**
* String name for
- * @see javax.media.opengl.GL2#GL_TEXTURE_COORD_ARRAY
+ * @see com.jogamp.opengl.GL2#GL_TEXTURE_COORD_ARRAY
*/
public static final String mgl_MultiTexCoord = GLPointerFuncUtil.mgl_MultiTexCoord;
}
@@ -77,18 +77,18 @@ public class FixedFuncUtil {
* @see #mgl_MultiTexCoord
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#GL_TEXTURE_COORD_ARRAY
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#glEnableClientState
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#glVertexPointer
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#glColorPointer
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#glNormalPointer
- * @see javax.media.opengl.fixedfunc.GLPointerFunc#glTexCoordPointer
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#GL_TEXTURE_COORD_ARRAY
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#glEnableClientState
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#glVertexPointer
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#glColorPointer
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#glNormalPointer
+ * @see com.jogamp.opengl.fixedfunc.GLPointerFunc#glTexCoordPointer
*/
public static String getPredefinedArrayIndexName(final int glArrayIndex) {